Class: BnmAPI::Data::BankBaseRate

Inherits:
Struct
  • Object
show all
Defined in:
lib/bnmapi/data/bank_base_rate.rb

Overview

not sure what is the difference between landing rate and financing rate the API response some returns landing rate and some returns financing rate including both in the data.

Instance Attribute Summary collapse

Instance Attribute Details

#bank_codeObject

Returns the value of attribute bank_code



5
6
7
# File 'lib/bnmapi/data/bank_base_rate.rb', line 5

def bank_code
  @bank_code
end

#bank_nameObject

Returns the value of attribute bank_name



5
6
7
# File 'lib/bnmapi/data/bank_base_rate.rb', line 5

def bank_name
  @bank_name
end

#base_financing_rateObject

Returns the value of attribute base_financing_rate



5
6
7
# File 'lib/bnmapi/data/bank_base_rate.rb', line 5

def base_financing_rate
  @base_financing_rate
end

#base_lending_rateObject

Returns the value of attribute base_lending_rate



5
6
7
# File 'lib/bnmapi/data/bank_base_rate.rb', line 5

def base_lending_rate
  @base_lending_rate
end

#base_rateObject

Returns the value of attribute base_rate



5
6
7
# File 'lib/bnmapi/data/bank_base_rate.rb', line 5

def base_rate
  @base_rate
end

#effective_dateObject

Returns the value of attribute effective_date



5
6
7
# File 'lib/bnmapi/data/bank_base_rate.rb', line 5

def effective_date
  @effective_date
end

#indicative_eff_lending_rateObject

Returns the value of attribute indicative_eff_lending_rate



5
6
7
# File 'lib/bnmapi/data/bank_base_rate.rb', line 5

def indicative_eff_lending_rate
  @indicative_eff_lending_rate
end

#last_updatedObject

Returns the value of attribute last_updated



5
6
7
# File 'lib/bnmapi/data/bank_base_rate.rb', line 5

def last_updated
  @last_updated
end